@@ -3,8 +3,8 @@
 from typing import Generator
 from datetime import datetime
 import gzip
-import requests
-import ijson
+import requests # type: ignore
+import ijson # type: ignore
 from dwh_oppfolging.misc.transforms import dict_to_string, string_to_sha256_hash, string_to_naive_norwegian_datetime
 from dwh_oppfolging.apis.brreg_api_v1_structs import PagedRequestForEmbeddedList, Update
 
@@ -81,7 +81,7 @@ def _get_unit_record_from_update_batch(orgnr_update_lkp: dict[str, Update], unit
     }
     headers = _build_headers(unit_name)
     list_key = unit_name
-    orgnr_record_lkp = {}
+    orgnr_record_lkp: dict = {}
     for facts in PagedRequestForEmbeddedList(url, params, headers, {}, page_size, list_key, timeout=100):
         orgnr_record_lkp |= {
             fact["organisasjonsnummer"]:
@@ -101,7 +101,7 @@ def get_latest_records_for_unit(download_date: datetime, last_modified_date: dat
     headers = _build_headers("oppdatering." + unit_name)
     list_key = "oppdaterte" + unit_name.capitalize()
     params = {"dato": last_modified_date.isoformat(timespec="milliseconds") + "Z"}
-    orgnr_record_lkp = {} # {orgnr from latest update for that orgnr: latest fact for that orgnr}
+    orgnr_record_lkp: dict = {} # {orgnr from latest update for that orgnr: latest fact for that orgnr}
     for updates in PagedRequestForEmbeddedList(url, params, headers, {}, page_size, list_key, timeout=100):
         # only keep the latest updates for each orgnr
         # since updates is already sorted with ascending update id, we can just overwrite
