@@ -1,4 +1,4 @@
-import requests
+import requests # type: ignore
 
 def is_dwh_consumer_alive(name: str):
     """returns true if dwh-consumer isalive endpoint returns OK"""
