@@ -99,7 +99,7 @@ def is_workflow_stale(
         table_name=table_name # type: ignore
     )
     try:
-        row: tuple = cur.fetchone()[0] # type: ignore
+        row: tuple = cur.fetchone() # type: ignore
         wflow_date: datetime = row[1]
         succeeded = bool(row[2])
     except (TypeError, IndexError) as exc:
